@@ -1,7 +1,7 @@
 /* 
  * Seahorse
  * 
- * Copyright (C) 2005 Nate Nielsen 
+ * Copyright (C) 2005 Stefan Walter
  * 
  * This program is free software; you can redistribute it and/or modify 
  * it under the terms of the GNU Lesser General Public License as
@@ -368,8 +368,11 @@ static gboolean
 refilter_now (CryptUIKeyStore* ckstore)
 {
     cryptui_keyset_refresh (ckstore->ckset);
+    
     gtk_tree_model_filter_refilter (ckstore->priv->filter);    
     ckstore->priv->filter_stag = 0;
+    
+    g_object_unref (ckstore);
     return FALSE;
 }
 
@@ -377,8 +380,12 @@ refilter_now (CryptUIKeyStore* ckstore)
 static void
 refilter_later (CryptUIKeyStore* ckstore)
 {
+    g_assert (ckstore->ckset != NULL);
+    
     if (ckstore->priv->filter_stag != 0)
         g_source_remove (ckstore->priv->filter_stag);
+        
+    g_object_ref (ckstore);
     ckstore->priv->filter_stag = g_timeout_add (200, (GSourceFunc)refilter_now, ckstore);
 }
 
@@ -826,6 +833,13 @@ cryptui_key_store_get_all_keys (CryptUIKeyStore *ckstore)
     return cryptui_keyset_get_keys (ckstore->ckset);
 }
 
+guint
+cryptui_key_store_get_count (CryptUIKeyStore *ckstore)
+{
+    g_return_val_if_fail (CRYPTUI_KEY_STORE (ckstore), 0);
+    return cryptui_keyset_get_count (ckstore->ckset);    
+}
+
 gboolean            
 cryptui_key_store_have_selected_keys (CryptUIKeyStore *ckstore, GtkTreeView *view)
 {
@@ -1003,7 +1017,7 @@ cryptui_key_store_set_selected_key (CryptUIKeyStore *ckstore, GtkTreeView *view,
 {
     GtkTreeModel* model = GTK_TREE_MODEL (ckstore->priv->store);
     GtkTreeSelection *sel;
-    GtkTreeIter iter;
+    GtkTreeIter iter, sel_iter;
     const gchar *key;
     gboolean have;
     
@@ -1019,16 +1033,19 @@ cryptui_key_store_set_selected_key (CryptUIKeyStore *ckstore, GtkTreeView *view,
             /* Is this row in our selection? */
             gtk_tree_model_get (model, &iter, CRYPTUI_KEY_STORE_KEY, &key, -1);
             have = (key && strcmp (selkey, key) == 0) ? TRUE : FALSE;
-            
-            /* Using checks so change data store */
-            if (ckstore->priv->use_checks)
+
+            if (ckstore->priv->use_checks) {
+                /* Using checks so change data store */
                 gtk_tree_store_set (ckstore->priv->store, &iter, CRYPTUI_KEY_STORE_CHECK, have, -1);
-                
-            /* Using normal selection */
-            else if (have)
-                gtk_tree_selection_select_iter (sel, &iter);
-            else
-                gtk_tree_selection_unselect_iter (sel, &iter);
+            } else {
+                key_store_get_view_iter (ckstore, &iter, &sel_iter);
+
+                /* Using normal selection */
+                if (have)
+                    gtk_tree_selection_select_iter (sel, &sel_iter);
+                else
+                    gtk_tree_selection_unselect_iter (sel, &sel_iter);
+            }
             
         } while (gtk_tree_model_iter_next (model, &iter));
     }
