@@ -1,7 +1,7 @@
 /*
  * Seahorse
  *
- * Copyright (C) 2004-2006 Nate Nielsen
+ * Copyright (C) 2004-2006 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,16 +18,14 @@
  * 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  */
- 
-#include <gnome.h>
-
 #include "config.h"
+
 #include "seahorse-util.h"
 #include "seahorse-marshal.h"
 #include "seahorse-operation.h"
 
 /* Override the DEBUG_OPERATION_ENABLE switch here */
-/* #define DEBUG_OPERATION_ENABLE 0 */
+#define DEBUG_OPERATION_ENABLE 0
 
 #ifndef DEBUG_OPERATION_ENABLE
 #if _DEBUG
@@ -228,50 +226,66 @@ seahorse_operation_cancel (SeahorseOperation *op)
 void
 seahorse_operation_copy_error  (SeahorseOperation *op, GError **err)
 {
-    g_return_if_fail (err == NULL || *err == NULL);
-    if (err) 
-        *err = op->error ? g_error_copy (op->error) : NULL;
+	g_return_if_fail (SEAHORSE_IS_OPERATION (op));
+	g_return_if_fail (err == NULL || *err == NULL);
+    
+	if (err) 
+		*err = op->error ? g_error_copy (op->error) : NULL;
 }
 
 const GError*       
 seahorse_operation_get_error (SeahorseOperation *op)
 {
-    return op->error;
+	g_return_val_if_fail (SEAHORSE_IS_OPERATION (op), NULL);
+	return op->error;
+}
+
+void
+seahorse_operation_display_error (SeahorseOperation *operation, 
+                                  const gchar *title, GtkWidget *parent)
+{
+	g_return_if_fail (SEAHORSE_IS_OPERATION (operation));
+	g_return_if_fail (operation->error);
+	seahorse_util_handle_error (operation->error, "%s", title);
 }
 
 gpointer
 seahorse_operation_get_result (SeahorseOperation *op)
 {
-    return op->result;
+	g_return_val_if_fail (SEAHORSE_IS_OPERATION (op), NULL);
+	return op->result;
 }
 
 void                
 seahorse_operation_wait (SeahorseOperation *op)
 {
-    seahorse_util_wait_until (!seahorse_operation_is_running (op));
+	g_return_if_fail (SEAHORSE_IS_OPERATION (op));
+
+	g_object_ref (op);
+	seahorse_util_wait_until (!seahorse_operation_is_running (op));
+	g_object_unref (op);
 }
 
 void
-seahorse_operation_watch (SeahorseOperation *operation, GCallback done_callback,
-                          GCallback progress_callback, gpointer userdata)
+seahorse_operation_watch (SeahorseOperation *operation, SeahorseDoneFunc done_callback,
+                          gpointer donedata, SeahorseProgressFunc progress_callback, gpointer progdata)
 {
-    typedef void (*DoneCb) (SeahorseOperation*, gpointer);
-    typedef void (*ProgressCb) (SeahorseOperation*, const gchar*, gdouble, gpointer);
+    g_return_if_fail (SEAHORSE_IS_OPERATION (operation));
 
     if (!seahorse_operation_is_running (operation)) {
         if (done_callback)
-            ((DoneCb)done_callback) (operation, userdata);
+            (done_callback) (operation, donedata);
         return;
     }
     
     if (done_callback)
-        g_signal_connect (operation, "done", done_callback, userdata);
+        g_signal_connect (operation, "done", G_CALLBACK (done_callback), donedata);
     
     if (progress_callback) {
-        ((ProgressCb)progress_callback) (operation, 
+        (progress_callback) (operation, 
                 seahorse_operation_get_message (operation),
-                seahorse_operation_get_progress (operation), userdata);
-        g_signal_connect (operation, "progress", progress_callback, userdata);
+                seahorse_operation_get_progress (operation), progdata);
+        g_signal_connect (operation, "progress", G_CALLBACK (progress_callback), progdata);
     }
 }
 
@@ -581,8 +595,8 @@ seahorse_multi_operation_take (SeahorseMultiOperation* mop, SeahorseOperation *o
     DEBUG_OPERATION (("[multi-operation 0x%08X] adding part: 0x%08X\n", (guint)mop, (guint)op));
     
     mop->operations = seahorse_operation_list_add (mop->operations, op);
-    seahorse_operation_watch (op, G_CALLBACK (multi_operation_done), 
-                              G_CALLBACK (multi_operation_progress), mop);
+    seahorse_operation_watch (op, (SeahorseDoneFunc)multi_operation_done, mop,
+                              (SeahorseProgressFunc)multi_operation_progress, mop);
 }
 
 /* -----------------------------------------------------------------------------
