@@ -22,9 +22,9 @@
 
 #include "config.h"
 
-#include "seahorse-util.h"
-#include "seahorse-key.h"
 #include "seahorse-gconf.h"
+#include "seahorse-object.h"
+#include "seahorse-util.h"
 
 #include "pgp/seahorse-pgp-module.h"
 
@@ -53,18 +53,12 @@ static const gchar *bad_filename_chars = "/\\<>|";
 void
 seahorse_util_show_error (GtkWidget *parent, const gchar *heading, const gchar *message)
 {
-	GtkWidget *error;
-	gchar *text;
+	GtkWidget *dialog;
     
 	g_return_if_fail (message || heading);
 	if (!message)
 		message = "";
     
-	if (heading)
-		text = g_strconcat("<big><b>", heading, "</b></big>\n\n", message, NULL);
-	else
-		text = g_strdup (message);
-	
 	if (parent) {
 		if (!GTK_IS_WIDGET (parent)) {
 			g_warn_if_reached ();
@@ -77,13 +71,22 @@ seahorse_util_show_error (GtkWidget *parent, const gchar *heading, const gchar *
 		}
 	}
 	
-	error = gtk_message_dialog_new_with_markup (GTK_WINDOW (parent), 
-	                                            GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-	                                            GTK_BUTTONS_CLOSE, "%s", text);
-	g_free (text);
+	dialog = gtk_message_dialog_new (GTK_WINDOW (parent), 
+	                                GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
+	                                GTK_BUTTONS_CLOSE, NULL);
+	if (heading)
+	    g_object_set (G_OBJECT (dialog),
+	                  "text", heading,
+	                  "secondary-text", message,
+	                  NULL);
+    else
+        g_object_set (G_OBJECT (dialog),
+	                  "text", message,
+	                  NULL);
 	
-	gtk_dialog_run (GTK_DIALOG (error));
-	gtk_widget_destroy (error);
+	
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 void
@@ -195,7 +198,7 @@ seahorse_util_get_display_date_string (const time_t time)
 	gchar *created_string;
 	
 	if (time == 0)
-		return "0";
+		return g_strdup ("");
 	
 	created_date = g_date_new ();
 	g_date_set_time_t (created_date, time);
@@ -262,8 +265,7 @@ seahorse_util_read_to_memory (GInputStream *input, guint *len)
 	if (len)
 		*len = string->len;
     
-	text = string->str;
-	g_string_free (string, FALSE);
+	text = g_string_free (string, FALSE);
 	g_free (buffer);
 	
 	return (guchar*)text;
@@ -421,28 +423,28 @@ seahorse_util_printf_fd (int fd, const char* fmt, ...)
 
 
 gchar*      
-seahorse_util_filename_for_keys (GList *keys)
+seahorse_util_filename_for_objects (GList *objects)
 {
-    SeahorseKey *skey;
-    gchar *t, *r;
+	SeahorseObject *object;
+	const gchar *name;
+	gchar *filename;
     
-    g_return_val_if_fail (g_list_length (keys) > 0, NULL);
+	g_return_val_if_fail (g_list_length (objects) > 0, NULL);
 
-    if (g_list_length (keys) == 1) {
-        g_return_val_if_fail (SEAHORSE_IS_KEY (keys->data), NULL);
-        skey = SEAHORSE_KEY (keys->data);
-        t = seahorse_key_get_simple_name (skey);
-        if (t == NULL)
-            t = g_strdup (_("Key Data"));
-    } else {
-        t = g_strdup (_("Multiple Keys"));
-    }
+	if (g_list_length (objects) == 1) {
+		g_return_val_if_fail (SEAHORSE_IS_OBJECT (objects->data), NULL);
+		object = SEAHORSE_OBJECT (objects->data);
+		name = seahorse_object_get_nickname (object);
+		if (name == NULL)
+			name = _("Key Data");
+	} else {
+		name = _("Multiple Keys");
+	}
     
-    g_strstrip (t);
-    g_strdelimit (t, bad_filename_chars, '_');
-    r = g_strconcat (t, SEAHORSE_EXT_ASC, NULL);
-    g_free (t);
-    return r;
+	filename = g_strconcat (name, SEAHORSE_EXT_ASC, NULL);
+	g_strstrip (filename);
+	g_strdelimit (filename, bad_filename_chars, '_');
+	return filename;
 }
 
 /** 
@@ -864,23 +866,23 @@ seahorse_util_chooser_show_archive_files (GtkDialog *dialog)
 }
 
 void
-seahorse_util_chooser_set_filename_full (GtkDialog *dialog, GList *keys)
+seahorse_util_chooser_set_filename_full (GtkDialog *dialog, GList *objects)
 {
     gchar *t = NULL;
     
-    if (g_list_length (keys) > 0) {
-        t = seahorse_util_filename_for_keys (keys);
+    if (g_list_length (objects) > 0) {
+        t = seahorse_util_filename_for_objects (objects);
         gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), t);
         g_free (t);
     }
 }
 
 void
-seahorse_util_chooser_set_filename (GtkDialog *dialog, SeahorseKey *skey)
+seahorse_util_chooser_set_filename (GtkDialog *dialog, SeahorseObject *object)
 {
-	GList *keys = g_list_append (NULL, skey);
-	seahorse_util_chooser_set_filename_full (dialog, keys);
-	g_list_free (keys);
+	GList *objects = g_list_append (NULL, object);
+	seahorse_util_chooser_set_filename_full (dialog, objects);
+	g_list_free (objects);
 }
     
 gchar*      
