@@ -745,13 +745,13 @@ on_refreshing (SeahorseContext *sctx, SeahorseOperation *operation, SeahorseWidg
 
 static const GtkActionEntry GENERAL_ENTRIES[] = {
 	{ "remote-menu", NULL, N_("_Remote") }, 
-	{ "app-quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q", 
+	{ "app-quit", GTK_STOCK_QUIT, NULL, "<control>Q", 
 	  N_("Close this program"), G_CALLBACK (on_app_quit) }, 
 	{ "file-new", GTK_STOCK_NEW, N_("_New..."), "<control>N", 
 	  N_("Create a new key or item"), G_CALLBACK (on_file_new) }, 
 	{ "file-import", GTK_STOCK_OPEN, N_("_Import..."), "<control>I", 
 	  N_("Import from a file"), G_CALLBACK (on_key_import_file) }, 
-	{ "edit-import-clipboard", GTK_STOCK_PASTE, N_("_Paste"), "<control>V", 
+	{ "edit-import-clipboard", GTK_STOCK_PASTE, NULL, "<control>V", 
 	  N_("Import from the clipboard"), G_CALLBACK (on_key_import_clipboard) }
 };
 
@@ -868,7 +868,6 @@ seahorse_key_manager_constructor (GType type, guint n_props, GObjectConstructPar
 	SeahorseKeyManager *self = SEAHORSE_KEY_MANAGER (G_OBJECT_CLASS (seahorse_key_manager_parent_class)->constructor(type, n_props, props));
 	GtkActionGroup* actions;
 	GtkToggleAction* action;
-	GtkTargetEntry* entries;
 	GtkTargetList* targets;
 	GtkWidget* widget;
 
@@ -920,7 +919,7 @@ seahorse_key_manager_constructor (GType type, guint n_props, GObjectConstructPar
 	                         "clicked", G_CALLBACK (on_new_button_clicked), self, 0);
 	
 	/* The notebook */
-	g_signal_connect_object (self->pv->notebook, "switch-page", G_CALLBACK (on_tab_changed), self, 0);
+	g_signal_connect_object (self->pv->notebook, "switch-page", G_CALLBACK (on_tab_changed), self, G_CONNECT_AFTER);
 	
 	/* Flush all updates */
 	seahorse_viewer_ensure_updated (SEAHORSE_VIEWER (self));
@@ -978,14 +977,16 @@ seahorse_key_manager_constructor (GType type, guint n_props, GObjectConstructPar
 	/* Set focus to the current key list */
 	widget = GTK_WIDGET (get_current_view (self));
 	gtk_widget_grab_focus (widget);
-	
+
+	g_signal_emit_by_name (self, "selection-changed");
+
 	/* To avoid flicker */
 	seahorse_widget_show (SEAHORSE_WIDGET (SEAHORSE_VIEWER (self)));
 	
 	/* Setup drops */
 	gtk_drag_dest_set (GTK_WIDGET (seahorse_viewer_get_window (SEAHORSE_VIEWER (self))), 
 	                   GTK_DEST_DEFAULT_ALL, NULL, 0, GDK_ACTION_COPY);
-	targets = gtk_target_list_new (entries, 0);
+	targets = gtk_target_list_new (NULL, 0);
 	gtk_target_list_add_uri_targets (targets, TARGETS_URIS);
 	gtk_target_list_add_text_targets (targets, TARGETS_PLAIN);
 	gtk_drag_dest_set_target_list (GTK_WIDGET (seahorse_viewer_get_window (SEAHORSE_VIEWER (self))), targets);
@@ -996,7 +997,6 @@ seahorse_key_manager_constructor (GType type, guint n_props, GObjectConstructPar
 	/* To show first time dialog */
 	g_timeout_add_seconds (1, (GSourceFunc)on_first_timer, self);
 	
-	g_signal_emit_by_name (self, "selection-changed");
 	g_signal_connect (seahorse_context_for_app (), "refreshing", G_CALLBACK (on_refreshing), self);
 
 	return G_OBJECT (self);
